@@ -4,15 +4,12 @@
 #' @description
 #' This function automates downloading, cleaning, reformatting of data from
 #' the Global Surface Summary of the Day (\acronym{GSOD}) data provided by the
-#' \href{https://data.noaa.gov/dataset/dataset/global-surface-summary-of-the-day-gsod}{US National Centers for Environmental Information (NCEI)},
+#' \href{https://www.ncei.noaa.gov/access/metadata/landing-page/bin/iso?id=gov.noaa.ncdc:C00516}{US National Centers for Environmental Information (NCEI)},
 #' Three additional useful elements: saturation vapour pressure (es), actual
 #' vapour pressure (ea) and relative humidity (RH) are calculated and returned
 #' in the final data frame using the improved August-Roche-Magnus approximation
 #' (Alduchov and Eskridge 1996).
 #'
-#' Parallel processing can be enabled using \code{\link[future]{plan}} to set
-#' up a parallel backend of your choice, \emph{e.g.},
-#' \code{future::plan("multisession")}.
 #'
 #' @details
 #'
@@ -131,7 +128,6 @@ get_GSOD <- function(years,
 
   # Load station list
   load(system.file("extdata", "isd_history.rda", package = "GSODR")) # nocov
-  setkeyv(isd_history, "STNID")
 
   # Validate user entered stations for existence in stations list from NCEI
   invisible(lapply(
@@ -177,7 +173,7 @@ get_GSOD <- function(years,
 
   GSOD <- .apply_process_csv(file_list, isd_history)
 
-  # remove any leftover files from download to prevent poluting a new run
+  # remove any leftover files from download to prevent polluting a new run
   file.remove(list.files(tempdir(), pattern = ".csv$", full.names = TRUE))
 
   return(GSOD)
